@@ -1,16 +1,19 @@
 package Perl6::Say;
 use strict;
 use warnings;
-our $VERSION = '0.05_003';
+our $VERSION = '0.05_004';
 use IO::Handle;
 use Scalar::Util 'openhandle';
 use Carp;
 
 sub say {
     my $currfh = select();
-    no strict 'refs';
-    my $handle = openhandle($_[0]) ? shift : \*$currfh;
-    use strict 'refs';
+    my $handle;
+    {
+        no strict 'refs';
+        $handle = openhandle($_[0]) ? shift : \*$currfh;
+        use strict 'refs';
+    }
     @_ = $_ unless @_;
     my $warning;
     local $SIG{__WARN__} = sub { $warning = join q{}, @_ };
@@ -24,7 +27,7 @@ sub say {
 
 no strict 'refs';
 sub import { *{caller() . '::say'} = \&say; }
-use strict;
+use strict 'refs';
 
 # Handle OO calls:
 
@@ -52,12 +55,16 @@ Perl6::Say - C<print> -- but no newline needed
 
     $fh->say('boo');       # same as:  print $fh 'boo', "\n";
 
+    say();                 # same as:  print "$_\n";
+
+    say undef;             # same as:  print "\n";
+
 =head1 DESCRIPTION
 
 =head2 General
 
-Implements a close simulation of C<say>, the Perl 6 function that provides the
-functionality of C<print> but allows you to omit the newline.
+Implements a close simulation of the C<say> function in Perl 6,
+which acts like C<print> but automatically appends a newline.
 
 Use it just like C<print> (except that it only supports the indirect object
 syntax when the stream is a bareword). That is, assuming the relevant
@@ -84,12 +91,6 @@ but not any of these:
 As demonstrated in the test suite accompanying this distribution,
 C<Perl6::Say::say()> can be used in all the following situations.
 
-    $_ = qq{Hello World};
-    say();                  # same as:  print qq{Hello World\n};
-
-    $_ = q{};
-    say();                  # same as:  print "\n";
-
     $string = q{};
     open FH, ">", \$string;
     say FH qq{Hello World};            # print to a string
@@ -126,14 +127,10 @@ the filehandle being used, rather than a global C<$/> variable).
 
 =head2 C<IO::Handle::say()>
 
-CPAN module IO::Handle, as of its version 1.27 (which, confusingly, is found
-in IO distribution 1.23 and later) implements its own C<say()> function which
-is similar to C<Perl6::Say::say()>.  Should you somehow be in the position of
-having to use a version of IO::Handle I<older> than 1.27 (thereby lacking
-C<IO::Handle::say()>) or should you somehow have C<undef>-ed that function,
-C<require>-ing Perl6::Say at that point will install C<Perl6::Say::say()> in
-the slot otherwise held by its IO::Handle namesake.  (See test file
-F<t/08_iohandle_say.t> for an illustration of this point.)
+IO::Handle version 1.27 or later (which, confusingly, is
+found in IO distribution 1.23 and later) also implements a C<say>
+method.   Perl6::Say provides its own C<say> method to IO::Handle
+if C<IO::Handle::say> is not available.
 
 =head1 WARNING
 
